{% extends "base.html" %}
{% block content %}
<form action="" method="post">
    {% csrf_token %}
    <table>
        {% for field in form %}
        <tr>
            <th>{{ field.label }}{% if field.field.required %}<span class="required">*</span>{% endif %}:</th>
            <td>{{ field }}</td>
            <td class="errors">{{ field.errors }}</td>
        </tr>
        {% endfor %}
    </table>
<input type="submit" />
</form>
{% endblock content %}
