{% extends 'base.html' %}
{% block submenu %}
<ul>
    <li><a href="../../">All</a></li>
    <li><a href="../../latest/">Latest news</a></li>
    <hr />
    <li><a href="../">{{ month|date:"Y" }}</a></li>
    <hr />
    <li><b>{{ month|date:"F" }}</b></li>
</ul>
{% endblock submenu %}
{% block content %}
<h1>{{ month|date:"Y-m" }}</h1>
<h2>
<a href="../{{ previous_month|date:"m" }}/">« {{ previous_month|date:"F" }}</a>
{{ month|date:"F" }}
{% if next_month %}
<a href="../{{ next_month|date:"m" }}/">{{ next_month|date:"F" }} »</a>
{% endif %}
</h2>
{% if object_list %}
<dl>
{% for entry in object_list %}
{% include 'blog/entry_with_fulldatetime.html' %}
{% endfor %}
</dl>
{% else %}
<p>No news.</p>
{% endif %}
{% endblock content %}
