{% extends 'nano/activation/base.html' %}
{% block content %}
<form action="" method="post">
    {% csrf_token %}
    {{ form }}
    <input type="submit" value="Activate" />
</form>
{% endblock content %}
