{% extends "base.html" %}
{% block title %}Signup: Finished!{% endblock title %}
{% block content %}
<h2>Welcome!</h2>

<p>You have now been signed up, logged in, and can really start using
this site.</p>
{% endblock content %}
