{% extends 'base.html' %}
{% block submenu %}
<ul>
    <li><b>All</b></li>
    <li><a href="./latest/">Latest news</a></li>
</ul>
{% endblock submenu %}
{% block content %}
{% if object_list %}
<dl>
{% for entry in object_list %}
{% include 'blog/entry_with_fulldatetime.html' %}
{% endfor %}
</dl>
{% else %}
<p>No news for this date.</p>
{% endif %}
{% endblock content %}
