{% extends 'base.html' %}
{% block submenu %}
<ul>
    <li><a href="../">All</a></li>
    <li><a href="../latest/">Latest news</a></li>
    <hr />
    <li><b>{{ year }}</b></li>
    <hr />
    {% for month in date_list %}
    <li><a href="./{{ month|date:"m" }}/">{{ month|date:"F" }}</a></li>
    {% endfor %}
</ul>
{% endblock submenu %}
{% block content %}
<h1>{{ year }}</h1>
<dl>
{% for entry in object_list %}
{% include 'blog/entry_with_fulldatetime.html' %}
{% endfor %}
</dl>
{% endblock content %}
