{% extends "base.html" %}
{% block title %} Send private message{% endblock title %}
{% block content %}
<h2>Send private message to {{ recipient.username }}</h2>
<form method="post" action="">
{% csrf_token %}
<table>
<tr><td>{{ form.subject }}</td></tr>
<tr><td>{{ form.text }}</td></tr>
<tr><td><input type="submit" /></td></tr>
</table>
</form>
{% endblock content %}

