{% extends "base.html" %}
{% block pagetitle %}Reset password{% endblock pagetitle %}
{% block content %}
<form action="" method="post">
    {% csrf_token %}
    <div><b>{{ form.username.label }}</b>
        {{ form.username }} 
        <span class="help">{{ form.username.help_text }}</span>
        <span class="errors">{{ form.username.errors }}</span>
        <input type="submit" value="Send email with new password"/>
    </div>
</table>
</form>
{% endblock content %}
