{% extends 'base.html' %}
{% block submenu %}
<ul>
    <li><a href="../">All</a></li>
    <li><b>Latest news</b></li>
    <hr />
    {% for year in date_list %}
    <li><a href="../{{ year|date:"Y" }}/">{{ year|date:"Y" }}</a></li>
    {% endfor %}
</ul>
{% endblock submenu %}
{% block content %}
{% if object_list %}
<h1>The {{ object_list.count }} latest news-items</h1>
<dl>
{% for entry in object_list %}
{% include 'blog/entry_with_fulldatetime.html' %}
{% endfor %}
</dl>
{% else %}
<p>No news for this date.</p>
{% endif %}
{% endblock content %}
