{% extends 'base.html' %}
{% block content %}
<h1>{{ day|date:"Y-m-d" }}</h1>
<h2><a href="../{{ previous_day|date:"d" }}/">{{ previous_day|date:"d" }}</a>
{{ day|date:"d" }}
<a href="../{{ next_day|date:"d" }}/">{{ next_day|date:"d" }}</a></h2>
<dl>
{% for entry in object_list %}
{% include 'blog/entry_with_time.html' %}
{% endfor %}
</dl>
{% endblock content %}
